require 'uu/os/rest/dto'
require 'uu/os/uesuri'

# Module Unicorn Universe
module UU

  # Module Finman
  module Finman

    # Module of finman Financial transaction
    module FinancialTransaction

      # DTO for setAttributes command of Expost payment Transaction.
      class ExpostPaymentSetAttributes < UU::OS::REST::DTO

        # Name of Financial Transaction. Cannot be empty.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Amount of the Financial Transaction without vat.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_without_vat

        # Amount of the Financial Transaction with vat.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_with_vat

        # Constant symbol.
        # @param [String]
        # @return [String]
        attr_accessor :constant_symbol

        # UESURI of Contract.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :contract_uri

        # Code of cost item.
        # @param [String]
        # @return [String]
        attr_accessor :cost_item_code

        # Number of credit account.
        # @param [String]
        # @return [String]
        attr_accessor :credit_account_number

        # UESURI of credit account artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_account_uri

        # Description for credit side.
        # @param [String]
        # @return [String]
        attr_accessor :credit_description

        # UESURI of credit financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_financial_category_uri

        # Credit vat date of the transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :credit_vat_date

        # Number of debit account.
        # @param [String]
        # @return [String]
        attr_accessor :debit_account_number

        # UESURI of debit account artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_account_uri

        # Description for debit side.
        # @param [String]
        # @return [String]
        attr_accessor :debit_description

        # UESURI of debit financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_financial_category_uri

        # Debit vat date of the transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :debit_vat_date

        # Type of financial transaction. CASH or NONCASH.
        # @param [FinancialTransactionType]
        # @return [FinancialTransactionType]
        attr_accessor :financial_transaction_type

        # Code of income item.
        # @param [String]
        # @return [String]
        attr_accessor :income_item_code

        # Invoice number of financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :invoice_number

        # Pay date of the transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :pay_date

        # Specific symbol.
        # @param [String]
        # @return [String]
        attr_accessor :specific_symbol

        # Variable symbol.
        # @param [String]
        # @return [String]
        attr_accessor :variable_symbol

        # Vat rate.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :vat_rate

        # Explicit exchange rate. Can be set only by role cast in Accounting Authorities.
        # Set to 0 to unset explicit exchange rate.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :explicit_exchange_rate

        # Explicit amount with VAT in opposite side currency. Can be set only by role cast in Accounting Authorities.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :explicit_amount

        # Related links(URI, label) in JSON format.
        # @param [String]
        # @return [String]
        attr_accessor :related_links

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def amount_without_vat
          attributes[:amountWithoutVat]
        end

        def amount_without_vat=(val)
          attributes[:amountWithoutVat] = val
        end

        def amount_with_vat
          attributes[:amountWithVat]
        end

        def amount_with_vat=(val)
          attributes[:amountWithVat] = val
        end

        def constant_symbol
          attributes[:constantSymbol]
        end

        def constant_symbol=(val)
          attributes[:constantSymbol] = val
        end

        def contract_uri
          attributes[:contractUri]
        end

        def contract_uri=(val)
          if val
            attributes[:contractUri] = UU::OS::UESURI.new(val)
          else
            attributes[:contractUri] = nil
          end
        end

        def cost_item_code
          attributes[:costItemCode]
        end

        def cost_item_code=(val)
          attributes[:costItemCode] = val
        end

        def credit_account_number
          attributes[:creditAccountNumber]
        end

        def credit_account_number=(val)
          attributes[:creditAccountNumber] = val
        end

        def credit_account_uri
          attributes[:creditAccountUri]
        end

        def credit_account_uri=(val)
          if val
            attributes[:creditAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditAccountUri] = nil
          end
        end

        def credit_description
          attributes[:creditDescription]
        end

        def credit_description=(val)
          attributes[:creditDescription] = val
        end

        def credit_financial_category_uri
          attributes[:creditFinancialCategoryUri]
        end

        def credit_financial_category_uri=(val)
          if val
            attributes[:creditFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditFinancialCategoryUri] = nil
          end
        end

        def credit_vat_date
          attributes[:creditVatDate]
        end

        def credit_vat_date=(val)
          attributes[:creditVatDate] = val
        end

        def debit_account_number
          attributes[:debitAccountNumber]
        end

        def debit_account_number=(val)
          attributes[:debitAccountNumber] = val
        end

        def debit_account_uri
          attributes[:debitAccountUri]
        end

        def debit_account_uri=(val)
          if val
            attributes[:debitAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitAccountUri] = nil
          end
        end

        def debit_description
          attributes[:debitDescription]
        end

        def debit_description=(val)
          attributes[:debitDescription] = val
        end

        def debit_financial_category_uri
          attributes[:debitFinancialCategoryUri]
        end

        def debit_financial_category_uri=(val)
          if val
            attributes[:debitFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitFinancialCategoryUri] = nil
          end
        end

        def debit_vat_date
          attributes[:debitVatDate]
        end

        def debit_vat_date=(val)
          attributes[:debitVatDate] = val
        end

        def financial_transaction_type
          attributes[:financialTransactionType]
        end

        def financial_transaction_type=(val)
          attributes[:financialTransactionType] = val
        end

        def income_item_code
          attributes[:incomeItemCode]
        end

        def income_item_code=(val)
          attributes[:incomeItemCode] = val
        end

        def invoice_number
          attributes[:invoiceNumber]
        end

        def invoice_number=(val)
          attributes[:invoiceNumber] = val
        end

        def pay_date
          attributes[:payDate]
        end

        def pay_date=(val)
          attributes[:payDate] = val
        end

        def specific_symbol
          attributes[:specificSymbol]
        end

        def specific_symbol=(val)
          attributes[:specificSymbol] = val
        end

        def variable_symbol
          attributes[:variableSymbol]
        end

        def variable_symbol=(val)
          attributes[:variableSymbol] = val
        end

        def vat_rate
          attributes[:vatRate]
        end

        def vat_rate=(val)
          attributes[:vatRate] = val
        end

        def explicit_exchange_rate
          attributes[:explicitExchangeRate]
        end

        def explicit_exchange_rate=(val)
          attributes[:explicitExchangeRate] = val
        end

        def explicit_amount
          attributes[:explicitAmount]
        end

        def explicit_amount=(val)
          attributes[:explicitAmount] = val
        end

        def related_links
          attributes[:relatedLinks]
        end

        def related_links=(val)
          attributes[:relatedLinks] = val
        end

      end
    end
  end
end

